define(
//begin v1.x content
{
	"scientificFormat": "#E0",
	"infinity": "∞",
	"superscriptingExponent": "×",
	"list": ";",
	"percentSign": "%",
	"minusSign": "‎-",
	"decimalFormat-short": "000T‏",
	"nan": "NaN",
	"plusSign": "‎+",
	"currencyFormat": "#,##0.00 ¤",
	"perMille": "‰",
	"group": ",",
	"percentFormat": "#,##0%",
	"decimalFormat-long": "‏000 טריליון",
	"decimalFormat": "#,##0.###",
	"currencyFormat-short": "¤000T‏",
	"timeSeparator": ":",
	"decimal": ".",
	"exponential": "E"
}
//end v1.x content
);